@@ -49,7 +49,7 @@ BacktestDensity <- function(Roll, lower, upper, K = 1000L, a = NULL, b = NULL) {
   vLS = EvaluateLogScore_Univ(t(mTheta), vY_oos, Dist, iT)
 
   mWCRPS = mWCRPS_backtest(vY_oos, t(mTheta), Dist, dLower, dUpper, iK, dA, dB)
-  colnames(mWCRPS) = c("uniform", "center", "tails", "tail_r", "tail_l")
+  colnames(mWCRPS) = c("uniform", "center", "tails", "tail_l", "tail_r")
 
   vAvg = c(NLS = -mean(vLS), apply(mWCRPS, 2L, mean))
 
@@ -59,3 +59,23 @@ BacktestDensity <- function(Roll, lower, upper, K = 1000L, a = NULL, b = NULL) {
 
   return(lOut)
 }
+
+FZLoss <- function(data, VaR, ES, alpha) {
+
+  vY = data
+  vVaR = VaR
+  dTau = alpha
+  vES  = ES
+
+  vY = as.numeric(vY)
+  vVaR = as.numeric(vVaR)
+  vES  = as.numeric(vES)
+
+  vHit = HitSequence(vY, vVaR)
+
+  vLoss = -vHit/(dTau * vES) * (vVaR - vY) + vVaR/vES + log(-vES) - 1.0
+
+  return(vLoss)
+
+}
+
